@@ -29,13 +29,13 @@ class MySQL(SalureConnect):
                 self.user = credentials['username']
                 self.password = credentials['password']
                 self.database = credentials['schema']
-                self.port = 3306 if credentials['port'] is None else credentials['port']
+                self.port = 3306 if credentials['port'] is None else int(credentials['port'])
             else:
                 self.host = os.getenv("MYSQL_HOST") if self.environment == 'prod' else os.getenv("MYSQL_STAGING_HOST")
                 self.user = os.getenv("MYSQL_USER")
                 self.password = os.getenv("MYSQL_PASSWORD")
                 self.database = os.getenv("MYSQL_DATABASE")
-                self.port = 3306 if os.getenv("MYSQL_PORT") is None else os.getenv("MYSQL_PORT")
+                self.port = 3306 if os.getenv("MYSQL_PORT") is None else int(os.getenv("MYSQL_PORT"))
 
     def raw_query(self, query, insert=False) -> Optional[Union[list, str]]:
         """
@@ -86,7 +86,7 @@ class MySQL(SalureConnect):
             else:
                 update_values += "`{}` = {}".format(columns[index], __map_strings(values[index]))
         update_values = update_values.replace('None', 'DEFAULT')
-        query = "UPDATE `{}` SET {} {};".format(table, update_values, filter)
+        query = "UPDATE {} SET {} {};".format(table, update_values, filter)
         if self.debug:
             print(query)
         if self.return_queries:
